==> aliyun-python-sdk-ccc-1.0.8.tar.gz: aliyun-python-sdk-ccc-1.0.8/aliyunsdkccc/request/v20170705/PickLocalNumberRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class PickLocalNumberRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'CCC', '2017-07-05', 'PickLocalNumber','ccc')

	def get_InstanceId(self):
		return self.get_query_params().get('InstanceId')

	def set_InstanceId(self,InstanceId):
		self.add_query_param('InstanceId',InstanceId)

	def get_CandidateNumbers(self):
		return self.get_query_params().get('CandidateNumbers')

	def set_CandidateNumbers(self,CandidateNumbers):
		for i in range(len(CandidateNumbers)):	
			if CandidateNumbers[i] is not None:
				self.add_query_param('CandidateNumber.' + str(i + 1) , CandidateNumbers[i]);

	def get_CalleeNumber(self):
		return self.get_query_params().get('CalleeNumber')

	def set_CalleeNumber(self,CalleeNumber):
		self.add_query_param('CalleeNumber',CalleeNumber)

==> aliyun-python-sdk-ccc-1.0.30.tar.gz: aliyun-python-sdk-ccc-1.0.30/aliyunsdkccc/request/v20170705/PickLocalNumberRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkccc.endpoint import endpoint_data

class PickLocalNumberRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'CCC', '2017-07-05', 'PickLocalNumber')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_InstanceId(self):
		return self.get_query_params().get('InstanceId')

	def set_InstanceId(self,InstanceId):
		self.add_query_param('InstanceId',InstanceId)

	def get_CandidateNumbers(self):
		return self.get_query_params().get('CandidateNumber')

	def set_CandidateNumbers(self, CandidateNumbers):
		for depth1 in range(len(CandidateNumbers)):
			if CandidateNumbers[depth1] is not None:
				self.add_query_param('CandidateNumber.' + str(depth1 + 1) , CandidateNumbers[depth1])

	def get_CalleeNumber(self):
		return self.get_query_params().get('CalleeNumber')

	def set_CalleeNumber(self,CalleeNumber):
		self.add_query_param('CalleeNumber',CalleeNumber)
